@@ -3,11 +3,12 @@
 #  E-mail: hwnorm@outlook.com               #
 #  Homepage: https://github.com/hwfan       #
 #############################################
-from DriveDownloader.netdrives.basedrive import DriveSession
 import base64
+from DriveDownloader.netdrives.basedrive import DriveSession
+
 class OneDriveSession(DriveSession):
-    def __init__(self, proxy, chunk_size=32768):
-        DriveSession.__init__(self, proxy, chunk_size)
+    def __init__(self, *args, **kwargs):
+        DriveSession.__init__(self, *args, **kwargs)
 
     def generate_url(self, url):
         '''
@@ -20,5 +21,5 @@ class OneDriveSession(DriveSession):
         return resultUrl
 
     def connect(self, url, custom_filename=''):
-        onedrive_url = self.generate_url(url)
-        DriveSession.connect(self, onedrive_url, download=True, custom_filename=custom_filename)
\ No newline at end of file
+        generated_url = self.generate_url(url)
+        DriveSession.connect(self, generated_url, custom_filename=custom_filename)
\ No newline at end of file
